Introduction
============

Before getting heavily into LinchPin, let's cover some of the basics. The topics below will cover everything needed to get going with LinchPin. For more advanced topics, refer to the :doc:`main documentation page <index>`.

.. toctree::
   :tocdepth: 1


* :doc:`installation`
* :doc:`getting_started`
* :doc:`configuration`
